/*
 * Copyright (c) 2002, 2003, 2004 Active Endpoints, Inc.
 *
 * This program is licensed under the terms of the GNU General Public License
 * Version 2 (the "License") as published by the Free Software Foundation, and 
 * the ActiveBPEL Licensing Policies (the "Policies").  A copy of the License
 * and the Policies were distributed with this program.  
 *
 * The License is available at:
 * http://www.gnu.org/copyleft/gpl.html
 *
 * The Policies are available at:
 * http://www.activebpel.org/licensing/index.html
 *
 * Unless required by applicable law or agreed to in writing, this program is
 * distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License and the Policies for
 * specific language governing the use of this program.
 */
package org.activebpel.samples.loan_approval.ws;
import org.activebpel.samples.loan_approval.Constants;
import org.activebpel.samples.loan_approval.loanProcessFault;
import org.activebpel.samples.loan_approval.util.RuntimeParams;
import java.math.BigInteger;

/**
 * The guts of a Web Service that approves or rejects a loan. This service
 * always returns the value defined in the runtime config XML file.
 * <p>
 * This class is deployed as a .jws (Java Web Service) file so that Axis can
 * turn it into a real SOAP Web Service.
 * 
 * @author Jim Menard, <a href="mailto:jimm@activebpel.org">jimm@activebpel.org</a>
 */
public class ApproverWebService {
   
/**
 * Returns whatever the config file tells us to. Throws an exception if the
 * config file tells us to.
 * <p>
 * A real assessor would return either "approved" or "denied" based upon the
 * values of the input parameters.
 *
 * @param firstName applicant's first name; ignored
 * @param name applicant's last name; ignored
 * @param amount amount applicant is requesting; ignored
 * @return whatever the config file tells us to; may even throw an exception
 */
public String approve(String firstName, String name, BigInteger amount)
    throws loanProcessFault
{
    String response = null;
    try {
	RuntimeParams rp = new RuntimeParams();
	response = rp.getText("/rundata/approver/accept");
    }
    catch (Exception e) {
	throw new loanProcessFault("approver", e.toString(),
				   Constants.UNEXPECTED_ERROR_CODE_STRING);
    }

    if (Constants.MAGIC_FAULT_STRING.equals(response))
	throw new loanProcessFault("approver");
    else
	return response;
}
}
